@@ -83,8 +83,6 @@ class MatchingTest(UnitTestCase):
 
         with patch('duplicity.path.ROPath.isdir') as mock_isdir:
             mock_isdir.return_value = True
-            # Can't pass the return_value as an argument to patch, as build
-            # system's mock is too old to support it.
 
             assert sf2(self.makeext("usr")) is None
             assert sf2(self.makeext("usr/local")) is None
@@ -116,18 +114,6 @@ class MatchingTest(UnitTestCase):
         assert sf2(self.makeext("what/ever.py")) == 0
         assert sf2(self.makeext("what/ever.py/foo")) == 0
 
-    def test_glob_re(self):
-        """test_glob_re - test translation of shell pattern to regular exp"""
-        assert self.Select.glob_to_re("hello") == "hello"
-        assert self.Select.glob_to_re(".e?ll**o") == "\\.e[^/]ll.*o"
-        r = self.Select.glob_to_re("[abc]el[^de][!fg]h")
-        assert r == "[abc]el[^de][^fg]h", r
-        r = self.Select.glob_to_re("/usr/*/bin/")
-        assert r == "\\/usr\\/[^/]*\\/bin\\/", r
-        assert self.Select.glob_to_re("[a.b/c]") == "[a.b/c]"
-        r = self.Select.glob_to_re("[a*b-c]e[!]]")
-        assert r == "[a*b-c]e[^]]", r
-
     def test_simple_glob_double_asterisk(self):
         """test_simple_glob_double_asterisk - primarily to check that the defaults used by the error tests work"""
         assert self.Select.glob_get_normal_sf("**", 1)
@@ -678,6 +664,36 @@ class ParseArgsTest(UnitTestCase):
                         ("--exclude", "**t/1/3")],
                        [(), ('2',), ('2', '1')])
 
+    def test_includes_files(self):
+        """Unit test the functional test test_includes_files"""
+        # Test for Bug 1624725
+        # https://bugs.launchpad.net/duplicity/+bug/1624725
+        self.root = Path("testfiles/select2/1/1sub1")
+        self.ParseTest([("--include", "testfiles/select2/1/1sub1/1sub1sub1"),
+                        ("--exclude", "**")],
+                       [(), ('1sub1sub1',), ('1sub1sub1',
+                                             '1sub1sub1_file.txt')])
+
+    def test_includes_files_trailing_slash(self):
+        """Unit test the functional test test_includes_files_trailing_slash"""
+        # Test for Bug 1624725
+        # https://bugs.launchpad.net/duplicity/+bug/1624725
+        self.root = Path("testfiles/select2/1/1sub1")
+        self.ParseTest([("--include", "testfiles/select2/1/1sub1/1sub1sub1/"),
+                        ("--exclude", "**")],
+                       [(), ('1sub1sub1',), ('1sub1sub1',
+                                             '1sub1sub1_file.txt')])
+
+    def test_includes_files_trailing_slash_globbing_chars(self):
+        """Unit test functional test_includes_files_trailing_slash_globbing_chars"""
+        # Test for Bug 1624725
+        # https://bugs.launchpad.net/duplicity/+bug/1624725
+        self.root = Path("testfiles/select2/1/1sub1")
+        self.ParseTest([("--include", "testfiles/s?lect2/1/1sub1/1sub1sub1/"),
+                        ("--exclude", "**")],
+                       [(), ('1sub1sub1',), ('1sub1sub1',
+                                             '1sub1sub1_file.txt')])
+
     def test_glob(self):
         """Test globbing expression"""
         self.ParseTest([("--exclude", "**[3-5]"),
@@ -786,10 +802,10 @@ testfiles/select**/2
                        [(), ('1',), ('1', '1'), ('1', '2'), ('1', '3')])
 
         self.root = Path("/")
-        self.ParseTest([("--exclude", "/home/*"),
-                        ("--include", "/home"),
+        self.ParseTest([("--exclude", "/tmp/*"),
+                        ("--include", "/tmp"),
                         ("--exclude", "/")],
-                       [(), ("home",)])
+                       [(), ("tmp",)])
 
     def test_exclude_after_scan(self):
         """Test select with an exclude after a pattern that would return a scan for that file"""
